@@ -183,6 +183,12 @@ static void
 gdm_server_ready (GdmServer *server)
 {
         g_debug ("GdmServer: Got USR1 from X server - emitting READY");
+
+        gdm_run_script (GDMCONFDIR "/Init", GDM_USERNAME,
+                        server->priv->display_name,
+                        NULL, /* hostname */
+                        server->priv->auth_file);
+
         g_signal_emit (server, signals[READY], 0);
 }
 
@@ -252,47 +258,6 @@ gdm_server_launch_sigusr1_thread_if_needed (void)
         }
 }
 
-/* We keep a connection (parent_dsp) open with the parent X server
- * before running a proxy on it to prevent the X server resetting
- * as we open and close other connections.
- * Note that XDMCP servers, by default, reset when the seed X
- * connection closes whereas usually the X server only quits when
- * all X connections have closed.
- */
-#if 0
-static gboolean
-connect_to_parent (GdmServer *server)
-{
-        int maxtries;
-        int openretries;
-
-        g_debug ("GdmServer: Connecting to parent display \'%s\'",
-                   d->parent_disp);
-
-        d->parent_dsp = NULL;
-
-        maxtries = SERVER_IS_XDMCP (d) ? 10 : 2;
-
-        openretries = 0;
-        while (openretries < maxtries &&
-               d->parent_dsp == NULL) {
-                d->parent_dsp = XOpenDisplay (d->parent_disp);
-
-                if G_UNLIKELY (d->parent_dsp == NULL) {
-                        g_debug ("GdmServer: Sleeping %d on a retry", 1+openretries*2);
-                        gdm_sleep_no_signal (1+openretries*2);
-                        openretries++;
-                }
-        }
-
-        if (d->parent_dsp == NULL)
-                gdm_error (_("%s: failed to connect to parent display \'%s\'"),
-                           "gdm_server_start", d->parent_disp);
-
-        return d->parent_dsp != NULL;
-}
-#endif
-
 static void
 gdm_server_init_command (GdmServer *server)
 {
@@ -311,6 +276,8 @@ gdm_server_init_command (GdmServer *server)
                 debug_options = "";
         }
 
+#define X_SERVER_ARG_FORMAT " -background none -noreset -verbose %s%s"
+
 #ifdef WITH_SYSTEMD
 
         /* This is a temporary hack to work around the fact that XOrg
@@ -349,13 +316,13 @@ gdm_server_init_command (GdmServer *server)
                 goto fallback;
         }
 
-        server->priv->command = g_strdup_printf (SYSTEMD_X_SERVER " -background none -verbose %s%s", verbosity, debug_options);
+        server->priv->command = g_strdup_printf (SYSTEMD_X_SERVER X_SERVER_ARG_FORMAT, verbosity, debug_options);
         return;
 
 fallback:
 #endif
 
-        server->priv->command = g_strdup_printf (X_SERVER " -background none -verbose %s%s", verbosity, debug_options);
+        server->priv->command = g_strdup_printf (X_SERVER X_SERVER_ARG_FORMAT, verbosity, debug_options);
 }
 
 static gboolean
@@ -736,14 +703,18 @@ server_child_watch (GPid       pid,
                 g_signal_emit (server, signals [DIED], 0, num);
         }
 
-        active_servers = g_slist_remove (active_servers, server);
-
         g_spawn_close_pid (server->priv->pid);
         server->priv->pid = -1;
 
         g_object_unref (server);
 }
 
+static void
+prune_active_servers_list (GdmServer *server)
+{
+        active_servers = g_slist_remove (active_servers, server);
+}
+
 static gboolean
 gdm_server_spawn (GdmServer    *server,
                   const char   *vtarg,
@@ -783,6 +754,11 @@ gdm_server_spawn (GdmServer    *server,
 
         active_servers = g_slist_append (active_servers, server);
 
+        g_object_weak_ref (G_OBJECT (server),
+                           (GWeakNotify)
+                           prune_active_servers_list,
+                           server);
+
         gdm_server_launch_sigusr1_thread_if_needed ();
 
         if (!g_spawn_async_with_pipes (NULL,
